@@ -1,6 +1,6 @@
 # Licensed under the LGPL: https://www.gnu.org/licenses/old-licenses/lgpl-2.1.en.html
-# For details: https://github.com/PyCQA/astroid/blob/main/LICENSE
-# Copyright (c) https://github.com/PyCQA/astroid/blob/main/CONTRIBUTORS.txt
+# For details: https://github.com/pylint-dev/astroid/blob/main/LICENSE
+# Copyright (c) https://github.com/pylint-dev/astroid/blob/main/CONTRIBUTORS.txt
 
 """Unit tests for module modutils (module manipulation utilities)."""
 import email
@@ -20,13 +20,12 @@ from pytest import CaptureFixture, LogCaptureFixture
 
 import astroid
 from astroid import modutils
-from astroid.const import PY310_PLUS
 from astroid.interpreter._import import spec
 
 from . import resources
 
 try:
-    import urllib3  # pylint: disable=unused-import
+    import urllib3  # type: ignore[import]
 
     HAS_URLLIB3_V1 = urllib3.__version__.startswith("1")
 except ImportError:
@@ -41,6 +40,7 @@ class ModuleFileTest(unittest.TestCase):
     package = "mypypa"
 
     def tearDown(self) -> None:
+        astroid.MANAGER.clear_cache()
         for k in list(sys.path_importer_cache):
             if "MyPyPa" in k:
                 del sys.path_importer_cache[k]
@@ -161,7 +161,7 @@ class ModPathFromFileTest(unittest.TestCase):
         )
 
     def test_raise_modpath_from_file_exception(self) -> None:
-        self.assertRaises(Exception, modutils.modpath_from_file, "/turlututu")
+        self.assertRaises(ImportError, modutils.modpath_from_file, "/turlututu")
 
     def test_import_symlink_with_source_outside_of_path(self) -> None:
         with tempfile.NamedTemporaryFile() as tmpfile:
@@ -174,6 +174,37 @@ class ModPathFromFileTest(unittest.TestCase):
             finally:
                 os.remove(linked_file_name)
 
+    def test_modpath_from_file_path_order(self) -> None:
+        """Test for ordering of paths.
+        The test does the following:
+        1. Add a tmp directory to beginning of sys.path via augmented_sys_path
+        2. Create a module file in sub directory of tmp directory
+        3. If the sub directory is passed as additional directory, module name
+           should be relative to the subdirectory since additional directory has
+           higher precedence."""
+        with tempfile.TemporaryDirectory() as tmp_dir:
+            with resources.augmented_sys_path([tmp_dir]):
+                mod_name = "module"
+                sub_dirname = "subdir"
+                sub_dir = tmp_dir + "/" + sub_dirname
+                os.mkdir(sub_dir)
+                module_file = f"{sub_dir}/{mod_name}.py"
+
+                with open(module_file, "w+", encoding="utf-8"):
+                    pass
+
+                # Without additional directory, return relative to tmp_dir
+                self.assertEqual(
+                    modutils.modpath_from_file(module_file), [sub_dirname, mod_name]
+                )
+
+                # With sub directory as additional directory, return relative to
+                # sub directory
+                self.assertEqual(
+                    modutils.modpath_from_file(f"{sub_dir}/{mod_name}.py", [sub_dir]),
+                    [mod_name],
+                )
+
     def test_import_symlink_both_outside_of_path(self) -> None:
         with tempfile.NamedTemporaryFile() as tmpfile:
             linked_file_name = os.path.join(tempfile.gettempdir(), "symlinked_file.py")
@@ -221,7 +252,7 @@ class ModPathFromFileTest(unittest.TestCase):
         """Test that we correctly find packages with an __init__.py file.
 
         Regression test for issue reported in:
-        https://github.com/PyCQA/astroid/issues/1327
+        https://github.com/pylint-dev/astroid/issues/1327
         """
         tmp_dir = Path(tempfile.gettempdir())
         self.addCleanup(os.chdir, os.getcwd())
@@ -290,6 +321,35 @@ class GetSourceFileTest(unittest.TestCase):
     def test_raise(self) -> None:
         self.assertRaises(modutils.NoSourceFile, modutils.get_source_file, "whatever")
 
+    def test_pyi(self) -> None:
+        package = resources.find("pyi_data")
+        module = os.path.join(package, "__init__.pyi")
+        self.assertEqual(modutils.get_source_file(module), os.path.normpath(module))
+
+    def test_pyi_preferred(self) -> None:
+        package = resources.find("pyi_data/find_test")
+        module = os.path.join(package, "__init__.py")
+        self.assertEqual(
+            modutils.get_source_file(module, prefer_stubs=True),
+            os.path.normpath(module) + "i",
+        )
+
+    def test_nonstandard_extension(self) -> None:
+        package = resources.find("pyi_data/find_test")
+        modules = [
+            os.path.join(package, "__init__.weird_ext"),
+            os.path.join(package, "standalone_file.weird_ext"),
+        ]
+        for module in modules:
+            self.assertEqual(
+                modutils.get_source_file(module, prefer_stubs=True),
+                module,
+            )
+            self.assertEqual(
+                modutils.get_source_file(module),
+                module,
+            )
+
 
 class IsStandardModuleTest(resources.SysPathSetup, unittest.TestCase):
     """
@@ -420,8 +480,12 @@ class ModuleInPathTest(resources.SysPathSetup, unittest.TestCase):
         assert modutils.module_in_path("data.module", datadir)
         assert modutils.module_in_path("data.module", (datadir,))
         assert modutils.module_in_path("data.module", os.path.abspath(datadir))
+        assert modutils.module_in_path("pyi_data.module", datadir)
+        assert modutils.module_in_path("pyi_data.module", (datadir,))
+        assert modutils.module_in_path("pyi_data.module", os.path.abspath(datadir))
         # "" will evaluate to cwd
         assert modutils.module_in_path("data.module", "")
+        assert modutils.module_in_path("pyi_data.module", "")
 
     def test_bad_import(self) -> None:
         datadir = resources.find("")
@@ -437,18 +501,6 @@ class ModuleInPathTest(resources.SysPathSetup, unittest.TestCase):
         assert not modutils.module_in_path("astroid", datadir)
 
 
-class BackportStdlibNamesTest(resources.SysPathSetup, unittest.TestCase):
-    """
-    Verify backport raises exception on newer versions
-    """
-
-    @pytest.mark.skipif(not PY310_PLUS, reason="Backport valid on <=3.9")
-    def test_import_error(self) -> None:
-        with pytest.raises(AssertionError):
-            # pylint: disable-next=import-outside-toplevel, unused-import
-            from astroid import _backport_stdlib_names  # noqa
-
-
 class IsRelativeTest(unittest.TestCase):
     def test_known_values_is_relative_1(self) -> None:
         self.assertTrue(modutils.is_relative("utils", email.__path__[0]))
@@ -499,6 +551,19 @@ class GetModuleFilesTest(unittest.TestCase):
         ]
         self.assertEqual(modules, {os.path.join(package, x) for x in expected})
 
+    def test_get_module_files_2(self) -> None:
+        package = resources.find("pyi_data/find_test")
+        modules = set(modutils.get_module_files(package, []))
+        expected = [
+            "__init__.py",
+            "__init__.pyi",
+            "module.py",
+            "module2.py",
+            "noendingnewline.py",
+            "nonregr.py",
+        ]
+        self.assertEqual(modules, {os.path.join(package, x) for x in expected})
+
     def test_get_all_files(self) -> None:
         """Test that list_all returns all Python files from given location."""
         non_package = resources.find("data/notamodule")
@@ -566,3 +631,18 @@ def test_find_setuptools_pep660_editable_install():
     with unittest.mock.patch.object(sys, "meta_path", new=[_EditableFinder]):
         assert spec.find_spec(["example"])
         assert spec.find_spec(["example", "subpackage"])
+
+
+def test_no_import_done_for_submodule_sharing_std_lib_name() -> None:
+    sys.path.insert(0, resources.find("data"))
+    try:
+        with pytest.raises(ImportError):
+            spec._find_spec_with_path(
+                [resources.find("data")],
+                "trace",
+                ("divide_by_zero", "trace"),
+                ("divide_by_zero",),
+                resources.find("data/divide_by_zero"),
+            )
+    finally:
+        sys.path.pop(0)
